==> knews-0.9.3.tar.gz: knews-0.9.3/Widgets/ScrListP.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef _ScrlistP_h
#define _ScrlistP_h

#include "ScrList.h"
#include "ShadowP.h"

typedef struct {
    XtPointer	extension;
} ScrListClassPart;

typedef struct _ScrListClassRec {
    CoreClassPart	core_class;
    ShadowClassPart	shadow_class;
    ScrListClassPart	scrlist_class;
} ScrListClassRec;

extern ScrListClassRec	scrListClassRec;

typedef struct {
    Pixel		foreground_pixel;
    Pixel		highlight_pixel;
    Cursor		dnd_cursor;
    XFontStruct		*font;
    XtCallbackList	resize_callback;
    XtCallbackList	select_callback;
    XtCallbackList	callback;
    XtCallbackList	second_callback;
    XtCallbackList	dnd_callback;
    long		n_alloc;
    Dimension		row_spacing;
    Dimension		internal_width;
    Dimension		internal_height;
    Dimension		internal_item_width;
    Dimension		internal_item_height;
    Dimension		pixmap_width;
    Dimension		pixmap_height;
    Dimension		pixmap_spacing;
    Dimension		preferred_lines;
    Dimension		preferred_columns;
    Boolean		depth_one;
    Boolean		at_least_one;
    Boolean		at_most_one;
    Boolean		allow_dnd;
    Boolean		use_pixmaps;
    /* private */
    char		**strings;
    Pixmap		*pixmaps;
    Boolean		*selected;
    long		first;
    long		lines;
    long		shown;
    long		n_sel;
    long		dnd_start;
    GC			default_gc;
    GC			selected_gc;
    GC			highlight_gc;
} ScrListPart;

typedef struct _ScrListRec {
    CorePart	core;
    ShadowPart	shadow;
    ScrListPart	scrlist;
} ScrListRec;

#endif /* _ScrListP_h */

==> knews-0.9.6-4.tar.gz: knews-0.9.6/Widgets/ScrListP.h <==
/* This software is Copyright 1995 by Karl-Johan Johnsson
 *
 * Permission is hereby granted to copy, reproduce, redistribute or otherwise
 * use this software as long as: there is no monetary profit gained
 * specifically from the use or reproduction of this software, it is not
 * sold, rented, traded or otherwise marketed, and this copyright notice is
 * included prominently in any copy made. 
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. ANY USE OF THIS
 * SOFTWARE IS AT THE USER'S OWN RISK.
 */
#ifndef ScrlistP_h
#define ScrlistP_h

#include "ScrList.h"
#include "ShadowP.h"

typedef struct {
    XtPointer	extension;
} ScrListClassPart;

typedef struct ScrListClassRec {
    CoreClassPart	core_class;
    ShadowClassPart	shadow_class;
    ScrListClassPart	scrlist_class;
} ScrListClassRec;

extern ScrListClassRec	scrListClassRec;

typedef struct {
    Pixel		foreground_pixel;
    Pixel		highlight_pixel;
    Cursor		dnd_cursor;
    XFontStruct		*font;
    XtCallbackList	resize_callback;
    XtCallbackList	select_callback;
    XtCallbackList	callback;
    XtCallbackList	second_callback;
    XtCallbackList	dnd_callback;
    long		n_alloc;
    Dimension		row_spacing;
    Dimension		internal_width;
    Dimension		internal_height;
    Dimension		internal_item_width;
    Dimension		internal_item_height;
    Dimension		pixmap_width;
    Dimension		pixmap_height;
    Dimension		pixmap_spacing;
    Dimension		preferred_lines;
    Dimension		preferred_columns;
    Boolean		depth_one;
    Boolean		at_least_one;
    Boolean		at_most_one;
    Boolean		allow_dnd;
    Boolean		use_pixmaps;
    /* private */
    Boolean		active;
    char		**strings;
    Pixmap		*pixmaps;
    Boolean		*selected;
    long		first;
    long		lines;
    long		shown;
    long		n_sel;
    long		dnd_start;
    GC			default_gc;
    GC			selected_gc;
    GC			highlight_gc;
} ScrListPart;

typedef struct ScrListRec {
    CorePart	core;
    ShadowPart	shadow;
    ScrListPart	scrlist;
} ScrListRec;

#endif /* ScrListP_h */
